==> tag_1.0.0.zip: server/src/main/java/cn/com/qmth/scancloud/entity/PackageResultEntity.java <==
package cn.com.qmth.scancloud.entity;

import java.util.List;

import cn.com.qmth.scancloud.entity.base.AuditingWithoutIdEntity;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.handlers.GsonTypeHandler;
import com.github.jeffreyning.mybatisplus.anno.MppMultiId;

// 签到表
@TableName(value ="sc_package_result",autoResultMap = true)
public class PackageResultEntity extends AuditingWithoutIdEntity {

    /**
     * 
     */
    private static final long serialVersionUID = -2443714675814813665L;
    @MppMultiId
    private Long examId;
    @MppMultiId
    private String packageCode;

    private String device;

    @TableField(value = "path", typeHandler = GsonTypeHandler.class)
    private List<String> path;

    private Boolean assigned;

    private Long uploadTime;

    public Long getExamId() {
        return examId;
    }

    public void setExamId(Long examId) {
        this.examId = examId;
    }

    public String getPackageCode() {
        return packageCode;
    }

    public void setPackageCode(String packageCode) {
        this.packageCode = packageCode;
    }

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    public List<String> getPath() {
        return path;
    }

    public void setPath(List<String> path) {
        this.path = path;
    }

    public Boolean getAssigned() {
        return assigned;
    }

    public void setAssigned(Boolean assigned) {
        this.assigned = assigned;
    }

    public Long getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(Long uploadTime) {
        this.uploadTime = uploadTime;
    }
}

==> tag_1.0.2.zip: server/src/main/java/cn/com/qmth/scancloud/entity/PackageResultEntity.java <==
package cn.com.qmth.scancloud.entity;

import java.util.List;

import cn.com.qmth.scancloud.entity.base.AuditingWithoutIdEntity;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.handlers.JacksonTypeHandler;
import com.github.jeffreyning.mybatisplus.anno.MppMultiId;

// 签到表
@TableName(value ="sc_package_result",autoResultMap = true)
public class PackageResultEntity extends AuditingWithoutIdEntity {

    /**
     * 
     */
    private static final long serialVersionUID = -2443714675814813665L;
    @MppMultiId
    private Long examId;
    @MppMultiId
    private String packageCode;

    private String device;

    @TableField(value = "path", typeHandler = JacksonTypeHandler.class)
    private List<String> path;

    private Boolean assigned;

    private Long uploadTime;

    public Long getExamId() {
        return examId;
    }

    public void setExamId(Long examId) {
        this.examId = examId;
    }

    public String getPackageCode() {
        return packageCode;
    }

    public void setPackageCode(String packageCode) {
        this.packageCode = packageCode;
    }

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    public List<String> getPath() {
        return path;
    }

    public void setPath(List<String> path) {
        this.path = path;
    }

    public Boolean getAssigned() {
        return assigned;
    }

    public void setAssigned(Boolean assigned) {
        this.assigned = assigned;
    }

    public Long getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(Long uploadTime) {
        this.uploadTime = uploadTime;
    }
}
